**Purpose**:
When you migrate virtual machines from Hyper-V to ProxmoxVE, you may run into several issues, from the disk formats being in `.raw` format instead of `.qcow2`, among other things.

One thing in particular, which is the reason for this document, is that if you migrate Rocky Linux from Hyper-V into ProxmoxVE using Veeam Backup & Replication, it will break the storage system so badly that the operating system will not boot.

Some high-level things to do to fix this are listed below, as well as commands to fix the booting issues when you get that far.

- Switch the processor type to `host`
- Fix the socket and cores are reversed, so a single socket CPU with 16 cores will appear like 16 sockets with one core each
- The VM will lose the adapter name of `eth0` and put something else like `ens18` that needs to be reconfigured manually to get networking functional again
- The storage controller needs to be switched to `VirtIO iSCSI`
- The VM may need you to switch the network adapter from `VirtIO` to `E1000` if you run `ethtool ens18` and find it's not detecting the link speed, and everything else is missing.
- The display driver needs switched to `SPICE`
- The operating system needs to have the bootloader and storage drivers regenerated, see the instructions below:
    - Boot from a Rocky Linux 9.5 installation ISO in the broken Rocky Linux VM
    - Select "**Troubleshooting -->**" in the boot menu
    - Select "**Rescue a Rocky Linux System**"
    - Press through the prompt with value `1` to select the automatic mounting of the detected operating system of the virtual machine
    - Press **<ENTER>** to enter the shell, then run the following commands to fix the booting issues

```sh
chroot /mnt/sysroot
dracut --force --regenerate-all
grub2-mkconfig -o /boot/grub2/grub.cfg
```

After this is done, you can turn off / sudo poweroff the VM and allow the VM to reboot.

!!! info "May Reboot Twice"
    During the process, you may notice that the VM reboots itself a second-time.  This is normal and can be left alone.  The VM will eventually reach the login screen.  Once you get this far, you can login and fix all of the *other* issues in the VM to get it stabilized.